get_prefix_bits_from_capacity

Function get_prefix_bits_from_capacity 

fn get_prefix_bits_from_capacity(
    capacity: u32,
    total_num_bits: usize,
    num_free_bits: usize,
) -> Vec<bool>
Function which returns a vector of the values for prefix bits according to which position we are in the range from 0 to total_num_bits - num_free_bits.